import machine
import kooka
import time
import fonts
from machine import Pin

red = None
green = None
blue = None
colour = None
red_on = None
green_on = None
blue_on = None
i = None

neopixel_P1 = (Pin("P1", Pin.OUT), bytearray(3))

def neopixel_set(np, *rgbs):
    for i in range(0, len(rgbs), 2):
        idx = (rgbs[i] - 1) * 3
        if idx < 0: continue
        np[1].extend(b"\x00" * ((idx + 3) - len(np[1])))
        rgb = rgbs[i + 1]
        if isinstance(rgb, str):
            if not (rgb.startswith("#") and len(rgb) == 7): continue
            rgb = int(rgb[1:], 16)
        np[1][idx + 1] = rgb >> 16
        np[1][idx + 0] = rgb >> 8
        np[1][idx + 2] = rgb
    kooka.neopixel_write(np[0], (510, 900, 900, 450), np[1])


red = (32 * 256) * 256
green = 32 * 256
blue = 32
colour = 0
red_on = 1
green_on = 1
blue_on = 1
_timer1000 = time.ticks_ms()
while True:
    if time.ticks_diff(time.ticks_ms(), _timer1000) >= 0:
        _timer1000 += 1000
        kooka.display.fill(0)
        kooka.display.setfont(fonts.mono6x7)
        kooka.display.print('Neopixels Demo', show=0)
        kooka.display.print('Red =', "{:2d}".format(round((red * red_on) / 65535)), show=0)
        kooka.display.print('Green =', "{:2d}".format(round((green * green_on) / 255)), show=0)
        kooka.display.print('Blue =', "{:2d}".format(round(blue * blue_on)), show=0)
        kooka.display.text(str('A-Ex  C-R  D-G  B-B'), int(0), int(55), int(1))
        kooka.display.show()
        if kooka.button_a.was_pressed():
            raise SystemExit
        if kooka.button_c.was_pressed():
            red_on = not red_on
        if kooka.button_d.was_pressed():
            green_on = not green_on
        if kooka.button_b.was_pressed():
            blue_on = not blue_on
        colour = red * red_on
        colour = green * green_on + colour
        colour = blue * blue_on + colour
        for i in range(1, 9):
            neopixel_set(neopixel_P1, i, colour)
            time.sleep(0.1)
        time.sleep(0.5)
        for i in range(8, 0, -1):
            neopixel_set(neopixel_P1, i, '#000000')
            time.sleep(0.02)
    kooka.display.show()
    machine.idle()

# Generated Blockly XML follows
# <xml xmlns="https://developers.google.com/blockly/xml"><variables><variable id="xs.eMAyg)1k8d^4#5XxD">red</variable><variable id=".:aglnK:t%o}F=D(i#)I">green</variable><variable id="gE6u[wtB^FuZ-xU+P9[~">blue</variable><variable id="SYH6_FfAU{d*-kA[zw*-">colour</variable><variable id="dpi3X%fD9gYD.xi:[j/u">red_on</variable><variable id="]G/Y=1Y/)g3+0KiWdXSd">green_on</variable><variable id="7x)kCqvUu;G/;t_~z$SI">blue_on</variable><variable id="z6,7,5:s$x|U9LG=pV#=">i</variable></variables><block type="variables_set" id="C_q~mwB%3:=VCNF[vK9(" x="230" y="70"><field name="VAR" id="xs.eMAyg)1k8d^4#5XxD">red</field><value name="VALUE"><block type="math_arithmetic" id="Nx?H]s%11m%]%/^GpguH"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="^m?_NaXUir9S_Olsjr|I"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="jTA,2ir.P8)e|5q-k/bl"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="h7(5OEXZ,YJTlz[A*us+"><field name="NUM">32</field></shadow></value><value name="B"><shadow type="math_number" id="gQnK3C`RL+z8(]E(x}B7"><field name="NUM">256</field></shadow></value></block></value><value name="B"><shadow type="math_number" id="lOnVu@s$d?ZPE[_=NrD;"><field name="NUM">256</field></shadow></value></block></value><next><block type="variables_set" id="`g*=}o;}uzim?pjP4PLR"><field name="VAR" id=".:aglnK:t%o}F=D(i#)I">green</field><value name="VALUE"><block type="math_arithmetic" id="l77h%6*$o#8yE3aosOb%"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="9MPE/FWb]?eK|+5v)4@O"><field name="NUM">32</field></shadow></value><value name="B"><shadow type="math_number" id="lZmyz_L5-E!8n+GbVhh["><field name="NUM">256</field></shadow></value></block></value><next><block type="variables_set" id="(Vjk7@v[)9eHkH}^N]z("><field name="VAR" id="gE6u[wtB^FuZ-xU+P9[~">blue</field><value name="VALUE"><block type="math_number" id="XFB2:h](Y6FV4^cSAA7x"><field name="NUM">32</field></block></value><next><block type="variables_set" id="AlS{w9~gf@1~}hzr:syD"><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field><value name="VALUE"><block type="math_number" id="]f]Eo]*_vr{3G)yAEFyB"><field name="NUM">0</field></block></value><next><block type="variables_set" id="T%BX?kmUx;h9{kC|)U,)"><field name="VAR" id="dpi3X%fD9gYD.xi:[j/u">red_on</field><value name="VALUE"><block type="math_number" id="/FXX`bxGAE?FD,Ax,$4b"><field name="NUM">1</field></block></value><next><block type="variables_set" id="9FAxht5;KqWP2[-6X#^i"><field name="VAR" id="]G/Y=1Y/)g3+0KiWdXSd">green_on</field><value name="VALUE"><block type="math_number" id="SSo3vhl/vUb_(})Gez`6"><field name="NUM">1</field></block></value><next><block type="variables_set" id="5pG4dERj@@VC3Q[4-i3|"><field name="VAR" id="7x)kCqvUu;G/;t_~z$SI">blue_on</field><value name="VALUE"><block type="math_number" id="HLK]j10sv-%~tNmQ1UDl"><field name="NUM">1</field></block></value></block></next></block></next></block></next></block></next></block></next></block></next></block><block type="event_every_seconds" id="|cAVc5Yl|am4,P81,h?|" x="230" y="310"><field name="T">1</field><statement name="DO"><block type="display_clear" id="wZy!v_yic;i_wKqnMI#W"><next><block type="display_setfont" id="._Cst^$(8]4f8)EXA@.t"><field name="FONT">mono6x7</field><next><block type="display_print" id="Lmw.Wo.iqJULb=u!!j(}"><value name="VALUE"><shadow type="text" id="t@pcF{3bCqw#heBiK6Yb"><field name="TEXT">Neopixels Demo</field></shadow></value><next><block type="display_print2" id="+E}F,rjh71^R#}rcW9o@"><value name="VALUE1"><shadow type="text" id="2A_J/#(q=M+:h1uT~eGg"><field name="TEXT">Red =</field></shadow></value><value name="VALUE2"><shadow type="math_number" id="^T/xUJEKBn59*WznO_^?"><field name="NUM">123</field></shadow><block type="str_format_int" id="ej}dLbA?JNDu_JvAPht*"><field name="W">2</field><value name="VALUE"><block type="math_arithmetic" id=";k+C@?}6C+aodN!QPTh9"><field name="OP">DIVIDE</field><value name="A"><shadow type="math_number" id="zr[8W3Bh}zG^0.ABHB#N"><field name="NUM">1</field></shadow><block type="math_arithmetic" id=";dBNL2Iixea1Jha^I4Rx"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="9!f2-fWB=tORzmg8Mwc`"><field name="NUM">1</field></shadow><block type="variables_get" id="O9%mKd`|8U.;r;f*yq5_"><field name="VAR" id="xs.eMAyg)1k8d^4#5XxD">red</field></block></value><value name="B"><shadow type="math_number" id="W#0T#;TGow^Le)P1Qv}G"><field name="NUM">65535</field></shadow><block type="variables_get" id="_qP#{~lc`Mo9$ngq4Y]j"><field name="VAR" id="dpi3X%fD9gYD.xi:[j/u">red_on</field></block></value></block></value><value name="B"><shadow type="math_number" id="MqqE3q.%{C`j[hf}.?D3"><field name="NUM">65535</field></shadow></value></block></value></block></value><next><block type="display_print2" id="5:)2kyR,a?N{i}UNJhr0"><value name="VALUE1"><shadow type="text" id=".vniwIV9i=Zi%aE^%.AP"><field name="TEXT">Green =</field></shadow></value><value name="VALUE2"><shadow type="math_number" id="?8bs}Cu5|c4`srUf6bL$"><field name="NUM">123</field></shadow><block type="str_format_int" id="LN704_?$IqJ}@#QcjX.!"><field name="W">2</field><value name="VALUE"><block type="math_arithmetic" id="[[B^V#,c/7F)55yS*Wn|"><field name="OP">DIVIDE</field><value name="A"><shadow type="math_number" id="ypm8Q.UpSG*xIQ!XL.k7"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="R7)cE=LHpCrAC?LRhIm^"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="Z$mR5STrdND0?h^sXyw3"><field name="NUM">1</field></shadow><block type="variables_get" id="Lbr6h@u7)neOhQSH+jLk"><field name="VAR" id=".:aglnK:t%o}F=D(i#)I">green</field></block></value><value name="B"><shadow type="math_number" id="Uj-#!zbEqs]RMCrs$]Iy"><field name="NUM">1</field></shadow><block type="variables_get" id="QIpTMqz]!ZnXg;:qk{Y}"><field name="VAR" id="]G/Y=1Y/)g3+0KiWdXSd">green_on</field></block></value></block></value><value name="B"><shadow type="math_number" id="!kHN)`zW,-5:3`y@A`_%"><field name="NUM">255</field></shadow></value></block></value></block></value><next><block type="display_print2" id="j@#nKfqwX~9u:UAWZpiE"><value name="VALUE1"><shadow type="text" id="U:u*wXHN!e%gLk)SJY=["><field name="TEXT">Blue =</field></shadow></value><value name="VALUE2"><shadow type="math_number" id="s|ESWoA:OSo*R/b=qtnw"><field name="NUM">123</field></shadow><block type="str_format_int" id="^daFH}g%CrcAYE3{qhw^"><field name="W">2</field><value name="VALUE"><block type="math_arithmetic" id="AIm]mZM71EZT7DBOY)|+"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="@6HP5)xeBQ(pK#ffeoeW"><field name="NUM">1</field></shadow><block type="variables_get" id="DOV3hRa8SHXFLH41mna]"><field name="VAR" id="gE6u[wtB^FuZ-xU+P9[~">blue</field></block></value><value name="B"><shadow type="math_number" id="[Z%GeUP4ao8aedT[0i4h"><field name="NUM">1</field></shadow><block type="variables_get" id="q);x6,W(K-cfsW([o4p*"><field name="VAR" id="7x)kCqvUu;G/;t_~z$SI">blue_on</field></block></value></block></value></block></value><next><block type="display_text" id="BlijZd)w$19_)Xgmgp9."><value name="VALUE"><shadow type="text" id="p1ulVm/UaA`/60$1+0(9"><field name="TEXT">A-Ex  C-R  D-G  B-B</field></shadow></value><value name="X"><shadow type="math_number" id="BlTqKNoZIwH:GE|Uz[~@"><field name="NUM">0</field></shadow></value><value name="Y"><shadow type="math_number" id="wBD.av-4+89ai081x@Xs"><field name="NUM">55</field></shadow></value><value name="C"><shadow type="math_number" id="nd]W1Q|34E-Yvx?rK9iE"><field name="NUM">1</field></shadow></value><next><block type="display_show" id="7fQCm1x*8R!04VAcg:h?"><next><block type="controls_if" id="_vcRSvh`;oMf`UipwcLj"><value name="IF0"><block type="button_was_pressed" id="=um80nbTnp]ZDY]-d:wQ"><field name="BUTTON">kooka.button_a.was_pressed()</field></block></value><statement name="DO0"><block type="exit_program" id="xUw13TWlY79?qtjMga^c"/></statement><next><block type="controls_if" id="LjZHb{+/]ZI;t2}#v}Rj"><value name="IF0"><block type="button_was_pressed" id="Hs}h^yE4#l];pm!h?xP2"><field name="BUTTON">kooka.button_c.was_pressed()</field></block></value><statement name="DO0"><block type="variables_set" id="c}-%b!YH8},atswj8y2j"><field name="VAR" id="dpi3X%fD9gYD.xi:[j/u">red_on</field><value name="VALUE"><block type="logic_negate" id="J6*,,^hfuFol${8t6:Bk"><value name="BOOL"><block type="variables_get" id="+)mGRR#pZ1vgnOyWM`)g"><field name="VAR" id="dpi3X%fD9gYD.xi:[j/u">red_on</field></block></value></block></value></block></statement><next><block type="controls_if" id="ChenIexe07jL0PZw(pB,"><value name="IF0"><block type="button_was_pressed" id="J3(N=XGi;?c5im#~pehd"><field name="BUTTON">kooka.button_d.was_pressed()</field></block></value><statement name="DO0"><block type="variables_set" id="{ITtpi1J};_cScF}erQe"><field name="VAR" id="]G/Y=1Y/)g3+0KiWdXSd">green_on</field><value name="VALUE"><block type="logic_negate" id="ixu#kJI;tFpa4nq5St/^"><value name="BOOL"><block type="variables_get" id="B(WZyrMQd+::kWjaFr8q"><field name="VAR" id="]G/Y=1Y/)g3+0KiWdXSd">green_on</field></block></value></block></value></block></statement><next><block type="controls_if" id="?.*/;g,l)~l,x(t5Qw,0"><value name="IF0"><block type="button_was_pressed" id="hc/xv}8sG~O!u`*~#dc^"><field name="BUTTON">kooka.button_b.was_pressed()</field></block></value><statement name="DO0"><block type="variables_set" id="c{t*r$zjZn(Yt0mX:6?H"><field name="VAR" id="7x)kCqvUu;G/;t_~z$SI">blue_on</field><value name="VALUE"><block type="logic_negate" id="6IS{CS2i)D^3h6:C~TcD"><value name="BOOL"><block type="variables_get" id="CRgT:|X$`S=Job=t!Lb:"><field name="VAR" id="7x)kCqvUu;G/;t_~z$SI">blue_on</field></block></value></block></value></block></statement><next><block type="variables_set" id="8=Ay:J83e#.kD|I-pUyr"><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field><value name="VALUE"><block type="math_arithmetic" id="0AH}Hx0hDK~iRiBF8U$1"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="%7o_}[_,@p1XS(6[:Mtg"><field name="NUM">1</field></shadow><block type="variables_get" id="|*$NriPFqye3%6T`}D5("><field name="VAR" id="xs.eMAyg)1k8d^4#5XxD">red</field></block></value><value name="B"><shadow type="math_number" id="|,S#{qH/hxhD]^J:|+5D"><field name="NUM">1</field></shadow><block type="variables_get" id="0ij|k7K!|ByWiitwQK8u"><field name="VAR" id="dpi3X%fD9gYD.xi:[j/u">red_on</field></block></value></block></value><next><block type="variables_set" id="o3VOKTnBV,B?Rei*AbX["><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field><value name="VALUE"><block type="math_mult_add" id=",C$Fq[S.Jp+0~g*8)izi"><value name="A"><shadow type="math_number" id="f|qvTd{cDpW[3(JClg!1"><field name="NUM">1</field></shadow><block type="variables_get" id="!T39)Li8I~T@8%BV2MW3"><field name="VAR" id=".:aglnK:t%o}F=D(i#)I">green</field></block></value><value name="B"><shadow type="math_number" id="6b1c];rBT3l?p_[{7)cq"><field name="NUM">2</field></shadow><block type="variables_get" id="M~LGF2Y9NsdR0|{,G)kY"><field name="VAR" id="]G/Y=1Y/)g3+0KiWdXSd">green_on</field></block></value><value name="C"><shadow type="math_number" id="xgjopx=K{m]?CN87A9QJ"><field name="NUM">3</field></shadow><block type="variables_get" id="8zG49z7{[=]~/g+20[V,"><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field></block></value></block></value><next><block type="variables_set" id="fLE[${n)5mjOSz,Gs+:g"><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field><value name="VALUE"><block type="math_mult_add" id="fi_Pl4`E~zO9957lr;dT"><value name="A"><shadow type="math_number" id="Z@U(#0:uN)fzAWKNytT|"><field name="NUM">1</field></shadow><block type="variables_get" id="X339*,,rsyd8Q;9NGdA["><field name="VAR" id="gE6u[wtB^FuZ-xU+P9[~">blue</field></block></value><value name="B"><shadow type="math_number" id="C~8lFqxu(I%D:XfZSFzE"><field name="NUM">2</field></shadow><block type="variables_get" id="M{uikWVW;GklkuOdH`=|"><field name="VAR" id="7x)kCqvUu;G/;t_~z$SI">blue_on</field></block></value><value name="C"><shadow type="math_number" id="k!$[~nDRPtzTnmg}U*aH"><field name="NUM">3</field></shadow><block type="variables_get" id="%60C*dBBr;+6{6;~{_/Y"><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field></block></value></block></value><next><block type="controls_for" id="{cW;V8V*#?wUheX}]M]w"><field name="VAR" id="z6,7,5:s$x|U9LG=pV#=">i</field><value name="FROM"><block type="math_number" id="4fHSg*^+k~6^bii@A0WS"><field name="NUM">1</field></block></value><value name="TO"><block type="math_number" id="FW|2-`d1zF`[Og$2NL^v"><field name="NUM">8</field></block></value><value name="BY"><block type="math_number" id="-%H)|lh__AalJ71[8b1b"><field name="NUM">1</field></block></value><statement name="DO"><block type="neopixel_set1" id="b3,7cT1E{2af1S}o?jEt"><field name="PIN">P1</field><value name="PIX1"><shadow type="math_number" id=")Oi-!h#X-,sK{Vifu;a["><field name="NUM">1</field></shadow><block type="variables_get" id="P?(j-2ekDIo3[;elw6@w"><field name="VAR" id="z6,7,5:s$x|U9LG=pV#=">i</field></block></value><value name="RGB1"><shadow type="text" id="W|Q.jodeNIm+^#fIz+i;"><field name="TEXT">#330033</field></shadow><block type="variables_get" id="zPrD`!bFb5,2F2ium_mF"><field name="VAR" id="SYH6_FfAU{d*-kA[zw*-">colour</field></block></value><next><block type="time_sleep" id="Qrgm=yP!}~bY8/ORo-/K"><value name="VALUE"><shadow type="math_number" id="cxP[b9oPY`!.q22[0]X)"><field name="NUM">0.1</field></shadow></value></block></next></block></statement><next><block type="time_sleep" id="b{j6(=q![qbe6uO~y]HC"><value name="VALUE"><shadow type="math_number" id="CQ47d.?+xd3i|QkoqVCz"><field name="NUM">0.5</field></shadow></value><next><block type="controls_for" id="+E5#+*seOVZ2XcC/t#|@"><field name="VAR" id="z6,7,5:s$x|U9LG=pV#=">i</field><value name="FROM"><block type="math_number" id="H^[p2*oL]l+WWfA#%p%|"><field name="NUM">8</field></block></value><value name="TO"><block type="math_number" id="L|eYkL3vbxKV*%ukHxNP"><field name="NUM">1</field></block></value><value name="BY"><block type="math_number" id="#ufLt{He/se3Lzi`{m=T"><field name="NUM">-1</field></block></value><statement name="DO"><block type="neopixel_set1" id="FL+v|hWk:7y$27K$@}qJ"><field name="PIN">P1</field><value name="PIX1"><shadow type="math_number" id="$/8bMgTNe[S74GOyov1M"><field name="NUM">1</field></shadow><block type="variables_get" id="KH]`5.5g1-iO{.#Z,oVw"><field name="VAR" id="z6,7,5:s$x|U9LG=pV#=">i</field></block></value><value name="RGB1"><shadow type="text" id="S$P(VqkL}QVxL]|c%M^E"><field name="TEXT">#000000</field></shadow></value><next><block type="time_sleep" id="E1$;q)[?cARWyr|^yG=d"><value name="VALUE"><shadow type="math_number" id="!I[!8Fq(!Q^@PG]:iOoL"><field name="NUM">0.02</field></shadow></value></block></next></block></statement></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></statement></block></xml>
