# File name: K_Vitals.py
# Copyright: The AustSTEM Foundation Limited
# Author: Tony Strasser based on work by Damien George
# Date created: 25 November 2018
# Date last modified: 25 November 2018
# MicroPython Version: 1.9.4 for the Kookaberry
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation.
# To the fullest extent permitted by law, AustSTEM absolutely disclaims 
# all warranties, expressed or implied, including, but not limited to, 
# implied warranties of merchantability and fitness for any particular purpose. 
# AustSTEM gives no warranty that this software will be free of errors, 
# or that defects in the software will be corrected,  
# See the GNU General Public License for more details.
#
# Reads the critical parameters of the Kookaberry plus the radio signal strength
# Begin code
import time, machine, kooka, fonts
import _kooka, kookactl, struct

adc = _kooka.ADCAll(12, 0xf0000)
disp = kooka.display

kooka.radio.enable()
kooka.radio.config(channel = 7, data_rate=0)    # Set to 250kbps to maximise range
rssi = 0
msg_count = 0

while not kooka.button_a.was_pressed():
    details = kooka.radio.receive_full()    #listen for a radio message
    if details:
        content, rssi, timestamp = details
        mbytes = str(content)
        msg = mbytes[2:len(mbytes)-2]
        msg_count += 1
    disp.fill(0)
    disp.setfont(fonts.mono8x8)
    disp.text('Vitals', 0, 6)
    disp.setfont(fonts.mono6x7)
    disp.text('A-exit', 0, 60)
    disp.setfont(fonts.mono6x7)
    disp.text('vref       = %.2f V' % adc.read_vref(), 0, 17)
    disp.text('core vref = %.2f V' % adc.read_core_vref(), 0, 25)
    disp.text('core vbat = %.2f V' % adc.read_core_vbat(), 0, 33)
    disp.text('core temp = %.2f C' % adc.read_core_temp(), 0, 41)
    disp.text('radio sig = %d dbm' % rssi, 0, 50)
    disp.text('Msgs %d' % msg_count, 60, 60)
    time.sleep_ms(100)
    disp.show()
